function HH = FreqResp( hh, ff )
% FreqResp - compute frequency response of LTI system
%
% inputs:
%     hh - vector of impulse repsonse coefficients
%     ff - vector of frequencies at which to evaluate frequency response
%
% output:
%     HH - frequency response at frequencies in ff.
%
% Syntax:
%     HH = FreqResp( hh, ff )

HH = zeros( size(ff) );
for kk = 1:length(hh)
    HH = HH + hh(kk)*exp(j*2*pi*(kk-1)*ff);
end